@@ -4,20 +4,17 @@
 # conda is distributed under the terms of the BSD 3-clause license.
 # Consult LICENSE.txt or http://opensource.org/licenses/BSD-3-Clause.
 
-from __future__ import print_function, division, absolute_import
+from __future__ import print_function, division, absolute_import, unicode_literals
 
 import argparse
 import os
 import subprocess
 import sys
-from difflib import get_close_matches
 
 from .common import add_parser_help
 from .find_commands import find_commands, find_executable
 from ..exceptions import CommandNotFoundError
 
-build_commands = {'build', 'index', 'skeleton', 'package', 'metapackage',
-                  'pipbuild', 'develop', 'convert'}
 
 _ARGCOMPLETE_DEBUG = False
 def debug_argcomplete(msg):
@@ -124,26 +121,12 @@ class ArgumentParser(argparse.ArgumentParser):
             else:
                 argument = None
             if argument and argument.dest == "cmd":
-                m = re.compile(r"invalid choice: '([\w\-]+)'").match(exc.message)
+                m = re.compile(r"invalid choice: u?'([\w\-]+)'").match(exc.message)
                 if m:
                     cmd = m.group(1)
                     executable = find_executable('conda-' + cmd)
                     if not executable:
-                        if cmd in build_commands:
-                            raise CommandNotFoundError(cmd, '''
-Error: You need to install conda-build in order to
-use the "conda %s" command.''' % cmd)
-                        else:
-                            message = "Error: Could not locate 'conda-%s'" % cmd
-                            possibilities = (set(argument.choices.keys()) |
-                                             build_commands |
-                                             set(find_commands()))
-                            close = get_close_matches(cmd, possibilities)
-                            if close:
-                                message += '\n\nDid you mean one of these?\n'
-                                for s in close:
-                                    message += '    %s' % s
-                            raise CommandNotFoundError(cmd, message)
+                        raise CommandNotFoundError(cmd)
 
                     args = [find_executable('conda-' + cmd)]
                     args.extend(sys.argv[2:])
@@ -162,7 +145,7 @@ use the "conda %s" command.''' % cmd)
 
         if self.prog == 'conda' and sys.argv[1:] in ([], ['help'], ['-h'], ['--help']):
             print("""
-other commands, such as "conda build", are avaialble when additional conda
+other commands, such as "conda build", are available when additional conda
 packages (e.g. conda-build) are installed
 """)
 
